# Orthanc - A Lightweight, RESTful DICOM Store
# Copyright (C) 2012-2015 Sebastien Jodogne, Medical Physics
# Department, University Hospital of Liege, Belgium
#
# This program is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# In addition, as a special exception, the copyright holders of this
# program give permission to link the code of its release with the
# OpenSSL project's "OpenSSL" library (or with modified versions of it
# that use the same license as the "OpenSSL" library), and distribute
# the linked executables. You must obey the GNU General Public License
# in all respects for all of the code used other than "OpenSSL". If you
# modify file(s) with this exception, you may extend this exception to
# your version of the file(s), but you are not obligated to do so. If
# you do not wish to do so, delete this exception statement from your
# version. If you delete this exception statement from all source files
# in the program, then also delete it here.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


if (${CMAKE_COMPILER_IS_GNUCXX})
  set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -Wall -pedantic -Werror -Wno-unused-function")
endif()

if (${CMAKE_SYSTEM_NAME} STREQUAL "Linux")
  # Linking with "pthread" is necessary, otherwise the software might crash
  # http://sourceware.org/bugzilla/show_bug.cgi?id=10652#c17
  link_libraries(pthread dl)
endif()

if (STANDALONE_BUILD)
  add_definitions(-DORTHANC_PLUGIN_STANDALONE=1)

  set(AUTOGENERATED_DIR "${CMAKE_CURRENT_BINARY_DIR}/AUTOGENERATED")
  set(AUTOGENERATED_SOURCES "${AUTOGENERATED_DIR}/EmbeddedResources.cpp")

  file(MAKE_DIRECTORY ${AUTOGENERATED_DIR})
  include_directories(${AUTOGENERATED_DIR})

  set(TARGET_BASE "${AUTOGENERATED_DIR}/EmbeddedResources")
  add_custom_command(
    OUTPUT
    "${AUTOGENERATED_DIR}/EmbeddedResources.h"
    "${AUTOGENERATED_DIR}/EmbeddedResources.cpp"
    COMMAND 
    python
    "${CMAKE_CURRENT_SOURCE_DIR}/Framework/EmbedResources.py"
    "${AUTOGENERATED_DIR}/EmbeddedResources"
    STATIC_RESOURCES
    ${RESOURCES_ROOT}
    DEPENDS
    "${CMAKE_CURRENT_SOURCE_DIR}/Framework/EmbedResources.py"
    ${STATIC_RESOURCES}
    )

else()
  add_definitions(
    -DORTHANC_PLUGIN_STANDALONE=0
    -DORTHANC_PLUGIN_RESOURCES_ROOT="${RESOURCES_ROOT}"
    )
endif()


list(APPEND AUTOGENERATED_SOURCES
  "${CMAKE_CURRENT_SOURCE_DIR}/Framework/Plugin.cpp"
  )